#include <qlabel.h>
#include <kiconloader.h>
#include <qapplication.h>
#include <kglobalsettings.h>

#include "acrilistwidget.h"

AcriListWidget::AcriListWidget(const AcriListInfo& info, bool odd, QWidget *parent)
    : AcriListItem(parent),
      m_acrilistInfo(info),
      m_odd(odd),
      m_selected(false)
{
    setFocusPolicy(QWidget::StrongFocus);
    setSelected(m_selected);

    itemTitle->setText("<h3>" + info.name() + "</h3>");
    itemTitle->installEventFilter(this);

    if (info.comment() != info.name())
    {
        itemDescription->setText(info.comment());
    }

    itemDescription->installEventFilter(this);

    KIconLoader * ldr = KGlobal::iconLoader();
    QPixmap icon = ldr->loadIcon(info.icon(), KIcon::Panel, KIcon::SizeLarge);
    itemPixmap->setPixmap(icon);
    itemPixmap->installEventFilter(this);
}

void AcriListWidget::keyPressEvent(QKeyEvent *e)
{
    if (e->key() == Qt::Key_Enter ||
        e->key() == Qt::Key_Return)
    {
        emit doubleClicked(this);
    }
    else if (e->key() == Qt::Key_Up)
    {
        QKeyEvent fakedKeyPress(QEvent::KeyPress, Qt::Key_BackTab, 0, 0);
        QKeyEvent fakedKeyRelease(QEvent::KeyRelease, Key_BackTab, 0, 0);
        QApplication::sendEvent(this, &fakedKeyPress);
        QApplication::sendEvent(this, &fakedKeyRelease);
    }
    else if (e->key() == Qt::Key_Down)
    {
        QKeyEvent fakedKeyPress(QEvent::KeyPress, Qt::Key_Tab, 0, 0);
        QKeyEvent fakedKeyRelease(QEvent::KeyRelease, Key_Escape, 0, 0);
        QApplication::sendEvent(this, &fakedKeyPress);
        QApplication::sendEvent(this, &fakedKeyRelease);
    }
    else
    {
        AcriListItem::keyPressEvent(e);
    }
}

void AcriListWidget::mousePressEvent(QMouseEvent *e)
{
    emit clicked(this);
    setFocus();
    QWidget::mousePressEvent(e);
}

void AcriListWidget::mouseDoubleClickEvent(QMouseEvent *e)
{
    if (!e->button() == QMouseEvent::LeftButton)
    {
        AcriListItem::mouseDoubleClickEvent(e);
        return;
    }

    emit doubleClicked(this);
}

void AcriListWidget::setSelected(bool selected)
{
    m_selected = selected;

    // for now just used to switch colours around =)
    if (m_selected)
    {
        setPaletteBackgroundColor(KGlobalSettings::highlightColor());
        setPaletteForegroundColor(KGlobalSettings::highlightedTextColor());
    }
    else if (m_odd)
    {
        setPaletteBackgroundColor(KGlobalSettings::baseColor());
        setPaletteForegroundColor(KGlobalSettings::textColor());
    }
    else
    {
        setPaletteBackgroundColor(KGlobalSettings::alternateBackgroundColor());
        setPaletteForegroundColor(KGlobalSettings::textColor());
    }
}

void AcriListWidget::setOdd(bool odd)
{
    m_odd = odd;
    setSelected(m_selected);
}

void AcriListWidget::focusInEvent(QFocusEvent*)
{
    emit clicked(this);
}
