/***************************************************************************
 *   Copyright (C) 2007 by Andreas Loibl   *
 *   andreas@andreas-loibl.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef ACRITOXINSTALLER_H
#define ACRITOXINSTALLER_H

#include <qvbox.h>
#include <qtimer.h>
#include <kcmdlineargs.h>
#include <kprogress.h>

#include "mainwizard.h"
#include "backend.h"

class AcritoxInstaller : public MainWizard
{
  Q_OBJECT

public:
  AcritoxInstaller(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
  ~AcritoxInstaller();
  QVBox* installOptionsListBox;
  QString encrypt( QString pwd );
  void enableDebug();
  void deviceMapSetButtonsEnabled();
  void handleCommandLine();
  /*$PUBLIC_FUNCTIONS$*/

public slots:
  virtual void slotHelp();
  virtual void confirmStateChanged();
  virtual void confirmInstallStateChanged();
  virtual void updateUserPasswordStatus();
  virtual void updateRootPasswordStatus();
  virtual void deviceMapButtonDownClicked();
  virtual void deviceMapButtonUpClicked();
  virtual void deviceMapCurrentChanged(QListBoxItem *) { deviceMapSetButtonsEnabled(); };
  virtual void confirmSwapStateChanged();
  virtual void back();
  virtual void next();
  
protected:
  /*$PROTECTED_FUNCTIONS$*/
//   void closeEvent( QCloseEvent * );

protected slots:
  virtual void updateProgress();
  virtual void reject();
  virtual void progressEnd();
  /*$PROTECTED_SLOTS$*/
  virtual void          prepareLogReceivedOutput();
  virtual void          runLogReceivedOutput();
  virtual void          installLogReceivedOutput();
  virtual void          handleBackendError(uint errorcode, QString error);
  virtual void          realnameChanged(const QString &name);

private:
  Backend* backend;
  void pageChanged();
  QString formatSizeLong( Q_ULLONG size );
  QTimer timer;
  void doInstall();
  void doUpdateInstall();
  void doRecoverInstall();
  void setStatusBusy(bool busy);
  bool statusBusy;
  bool statusFinished;
  KProgressDialog* progressDlg;
  bool isUbuntu;
  QStringList adjustmentsList;

private slots:
};

#endif

